=====
envi
=====


.. image:: https://img.shields.io/pypi/v/envi.svg
    :target: https://pypi.python.org/pypi/envi

.. image:: https://img.shields.io/travis/OvalMoney/envi.svg
    :target: https://travis-ci.org/OvalMoney/envi

.. image:: https://readthedocs.org/projects/envi/badge/?version=latest
    :target: https://envi.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/OvalMoney/envi/shield.svg
    :target: https://pyup.io/repos/github/OvalMoney/envi/
    :alt: Updates


minimal environment variables reader


* Free software: MIT license
* Documentation: https://envi.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
